# mcpid

Simple API to get a numpy array of particle data from their MCPID codes.

The original data was taken from scikit-hep's excellent Particle package,
and you should probably use their work instead.
